function RunSingleTrial( output, trialData , display, tr)
    %initialize output
    output.message = 'GoodTrial'; %assume a good trial till proven otherwise
    output.RT = 0;
    %these define the rectangle dimansions of the fixation, cue and probe 
    fixRect = [display.fixXLoc - display.fixHalfBox...
            display.fixYLoc - display.fixHalfBox...
            display.fixXLoc + display.fixHalfBox...
            display.fixYLoc + display.fixHalfBox];
        
    cueRect = [trialData.cueXLoc - display.cueHalfBox...
            trialData.cueYLoc - display.cueHalfBox...
            trialData.cueXLoc + display.cueHalfBox...
            trialData.cueYLoc + display.cueHalfBox];
        
    probeRect = [trialData.probeXLoc - display.cueHalfBox...
                trialData.probeYLoc - display.cueHalfBox...
                trialData.probeXLoc + display.cueHalfBox...
                trialData.probeYLoc + display.cueHalfBox];
    
    space = KbName('space');
    escape = KbName('Escape');
    
    %display fixation and start trial timer
    Screen('DrawTexture', display.w, display.probe , [],[display.fixXLoc - display.fixHalfBox display.fixYLoc - display.fixHalfBox  display.fixXLoc + display.fixHalfBox  display.fixYLoc + display.fixHalfBox ]);         
    trialStart = Screen('Flip', display.w );%to clear buffer  
    
    %event flags.  set these when the events happen in the timing loop
    maxTime = trialStart + display.maxProbeResponse;
    probePresentTime = trialStart + trialData.probeOnset;
    cuePresentedTime = trialStart + display.cueOnset;
    cueDisabledTime = trialStart + display.cueOnset + display.cueDuration;
    probeOnset = 0;
    probePresentedFlag = 0;
    cuePresentedFlag =1;
    cueDisabledFlag =1;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%primary timing loop.  
%each if statement in here checks for one of our events like cue onset, or
%button response
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    while (GetSecs() < maxTime  && output.RT ==0)

        %%%%%%%%%%%%%%%%%%%%%%%%
        % 1) poll for a keypress.  all keys are errors at this point
        [KeyIsDown, endrt, KeyCode]=KbCheck();
        if (KeyIsDown==1)
            output.RT = GetSecs() - probeOnset;
            
            if probePresentedFlag == 0
               output.message = 'EARLY_RESPONSE';
            end
             WaitSecs(.2);
            %return;
        end
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %2) is it time to present the cue?
        if (GetSecs() > cuePresentedTime && cuePresentedFlag ==0)
            %first redraw fixation
            Screen('DrawTexture', display.w, display.probe , [],fixRect);         
            %time to display cue
            Screen('DrawTexture', display.w, display.whiteProbe , [], cueRect);         
            Screen('Flip', display.w );%to clear buffer  
            cuePresentedFlag =1;
        end
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %3)Should we turn OFF the cue? This just redraws fixation alone 
        if GetSecs() > cueDisabledTime && cuePresentedFlag ==1 && cueDisabledFlag == 0
            %first redraw fixation
            Screen('DrawTexture', display.w, display.probe , [],fixRect);         
            probeOnset = Screen('Flip', display.w );%to clear buffer  
            cueDisabledFlag =1;
        end
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %4)is it time to present the probe?
        if GetSecs() > probePresentTime && probePresentedFlag ==0
            %first redraw fixation
            Screen('DrawTexture', display.w, display.probe , [],fixRect);         
                %then the probe
            Screen('DrawTexture', display.w, display.redProbe , [],probeRect);         
            probeOnset = Screen('Flip', display.w );%to clear buffer  
            probePresentedFlag =1;
        end
        
        
        
    end    
    %print the results of this trial to file
    fprintf(output.resultsFile,'%d\t%d\n',tr,display.cueOnset);
    
    %make sure space is released    
    [KeyIsDown, endrt, KeyCode]=KbCheck();
    while (KeyIsDown==1)
        [KeyIsDown, endrt, KeyCode]=KbCheck();
    end;
    return;
end

