function [output, display, trials] = SetUpTrials( subNo, w)
%set all variables for running the blocks.  
%these values canbe hard coded in this file, or they can be read in from a
%text file (not yet implemented)
%for this experiment....
        
% Block 0:  Training  
% Block 1:  all conditions are now randomized within this block
% including 

%%%%%%%%%%%%%%%%%%%%%%
% file handling
%%%%%%%%%%%%%%%%%%%%%%

%some of these are redining the base matlab colours, but oh well.
    display.w = w;  
    display.white=WhiteIndex(w);
    display.black=BlackIndex(w);
    display.grey = (WhiteIndex(w)+BlackIndex(w))/2;
    
    % Define filenames of input files and result file:
    output.filename = strcat('SimpleCue_',num2str(subNo),'.dat'); % name of cueing data file to write to

    % check for existing result file to prevent accidentally overwriting
    % files from a previous subject/session (except for subject numbers > 99):
    if subNo>99
        fopen(output.filename, 'rt');  % its a test trial
    else
        while (fopen(output.filename, 'rt')~=-1)
            subNo= subNo+1;
            output.filename = strcat('SimpleCue_',num2str(subNo),'.dat'); % name of cueing data file to write to
        end;
        strcat('Result data file already exists! Choosing: ', num2str(subNo))
    end
    output.resultsFile = fopen(output.filename,'wt'); % open ASCII file for writing
%header line
    
    
    [display.width, display.height]=Screen('WindowSize', w);
    
    %these variables are common to all experiment blocks
    display.centerX                   = display.width/2;
    display.centerY                   = display.height/2;
    centW = 40.0; %screen width, cm
    centD = 50.0; %dist to screen, cm

    rad = 2.0*atan(centW/(centD*2));%radians of entire monitor
    deg = rad*(180/pi);%Degrees of entire monitor
    display.pixelsperdegree  = display.width/deg;  %pixels per degree
    
%     %No fixation needed
    display.fixXLoc                   = display.centerX;
    display.fixYLoc                   = display.centerY;    
    display.fixHalfBox                = 10;      %max distance we allow to still be on target for fix and saccade land 

    display.cueDistance                 =floor(5*display.pixelsperdegree);
    display.cueOnset                  =0.500;
    
    %half means the size of the square from centre to edge
    display.cueHalfBox              = floor(1*display.pixelsperdegree);
    display.cueDuration             = 0.1; %duration in seconds
    display.maxProbeResponse          = 5.0; %duration in seconds after 2nd targ
    
    display.halfStimSize              = floor(1*display.pixelsperdegree);
    %fix also potential target (but not cue)
    display.stimDir               ='Stim/';
    
    display.cueRightX               = display.centerX + display.cueDistance;
    display.cueLeftX               = display.centerX - display.cueDistance;
    display.cueY                     = display.centerY;
%every image has alpha
alpha = 1;
    [ display.probe ] = Image2Texture( 'probe.png', display.stimDir,w );
    [ display.redProbe ] = Image2Texture( 'red.png', display.stimDir,w );
    [ display.whiteProbe ] = Image2Texture( 'white.png', display.stimDir,w );
    [ display.blackProbe ] = Image2Texture( 'black.png', display.stimDir,w );

    %number of trials will be factor1*factor2*... * iterations
    factor.cueLoc                  = 2; 
    factor.probeLoc                  = 2;
    
    %each facor representing the 2 possible locations.  and they only
    %differ in x
    factor.loc(1).x                 = display.cueRightX;
    factor.loc(2).x                 = display.cueLeftX;
    %number of iterations to run the other factors
    factor.iterations                = 1; % 10 should get us 960 trials here ->me thinks 8*48=240 (two practice blocks?, leaves us with 30 trials per condition)... 
       
        % params for the probe
    display.soaMin                = 0.5; % in seconds after saccade land
    display.soaMax                = 1.3; % in sec1onds after saccade land
 
     
    trialNum = 0;

    %one loop for each factor in the experiment
    for i=1:factor.iterations
        for c=1:factor.cueLoc
            for p=1:  factor.probeLoc
                    %make an array out of these trials, all block 2, 
                    trialNum = trialNum+1;
                    %central is first in array
                      
                    trials(trialNum).cueXLoc = factor.loc(c).x ;
                    trials(trialNum).cueYLoc = display.cueY ;
                    trials(trialNum).probeXLoc = factor.loc(p).x ;
                    trials(trialNum).probeYLoc = display.cueY;
                    
                    soa = rand()*(display.soaMax-display.soaMin);                    
                    trials(trialNum).probeOnset = display.cueOnset+display.soaMin +soa;
             end
        end
    end
    
    %randomize trials
   randomOrder = randperm(size(trials,2)); %create random order from that.
   trials = trials(randomOrder);
    
end

